All of the people who have made at least one contribution to conda-mirror.
Authors are sorted by number of commits.

* Eric Dill
* Magnus Holm
* Ilan Schnell
* Peter Parente
* Anthony Scopatz
* John Kirkham
* Michael Peters
* magnuhho
* Uwe L. Korn
* Diogo Pereira
* Jens Nie
* Willi Rath
* David Kent
* Johannes Haberl
* Marius van Niekerk
* Bruno Oliveira
